"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _checkTargetUrl = _interopRequireDefault(require("./check-target-url"));

var _moduleReplication = require("@resolve-js/module-replication");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getReplicationState = async ({
  targetApplicationUrl
}) => {
  const checkResult = (0, _checkTargetUrl.default)(targetApplicationUrl);

  if (checkResult != null) {
    return checkResult;
  }

  const defaultValues = {
    paused: false,
    iterator: null,
    successEvent: null,
    locked: false
  };

  try {
    const response = await (0, _nodeFetch.default)(`${targetApplicationUrl}${_moduleReplication.REPLICATION_STATE.endpoint}`);

    if (response.status >= 400) {
      return {
        statusAndData: {
          status: 'serviceError',
          data: {
            name: response.statusText,
            message: await response.text()
          }
        },
        ...defaultValues
      };
    }

    return await response.json();
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      return {
        statusAndData: {
          status: 'serviceError',
          data: {
            name: error.name,
            message: error.message
          }
        },
        ...defaultValues
      };
    } else {
      return {
        statusAndData: {
          status: 'criticalError',
          data: {
            name: error.name,
            message: error.message
          }
        },
        ...defaultValues
      };
    }
  }
};

var _default = getReplicationState;
exports.default = _default;
//# sourceMappingURL=get-replication-state.js.map