import type { CommonAdapterPool, CommonAdapterOptions, AdapterOperations, AdapterConnection, AdapterImplementation, StoreApi, OmitObject } from '@resolve-js/readmodel-base';
import { ReplicationState, OldEvent, OldSecretRecord } from '@resolve-js/eventstore-base';
export * from '@resolve-js/readmodel-base';
export declare type DropReadModelMethod = (pool: AdapterPool, readModelName: string) => Promise<void>;
export declare type GetReplicationState = (pool: AdapterPool) => Promise<ReplicationState>;
export declare type CallReplicateResult = {
    type: 'launched' | 'unknown' | 'serverError' | 'clientError';
    httpStatus: number;
    message: string;
};
export declare type CallReplicate = (pool: AdapterPool, events: OldEvent[], secretsToSet: OldSecretRecord[], secretsToDelete: Array<OldSecretRecord['id']>, iterator: ReplicationState['iterator']) => Promise<CallReplicateResult>;
export declare type SetReplicationPaused = (pool: AdapterPool, paused: boolean) => Promise<void>;
export declare type AdapterOptions = CommonAdapterOptions & {
    targetApplicationUrl: string;
    preferRegularLoader?: boolean;
};
export declare type InternalMethods = {
    dropReadModel: DropReadModelMethod;
    getReplicationState: GetReplicationState;
    callReplicate: CallReplicate;
    setReplicationPaused: SetReplicationPaused;
    occupyReplication: (pool: AdapterPool, duration: number) => Promise<{
        status: 'success' | 'alreadyLocked' | 'serviceError' | 'error';
        message?: string;
    }>;
    releaseReplication: (pool: AdapterPool) => Promise<void>;
};
export declare type ArrayOrSingleOrNull<T> = Array<T> | T | null;
export declare type AdapterPool = CommonAdapterPool & {
    targetApplicationUrl: string;
    preferRegularLoader: boolean;
} & {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterOperations<AdapterPool>[K];
} & {
    [K in keyof StoreApi<CommonAdapterPool>]: StoreApi<AdapterPool>[K];
} & InternalMethods;
export declare type CurrentAdapterConnection = AdapterConnection<AdapterPool, OmitObject<AdapterOptions, CommonAdapterPool>>;
export declare type ExternalMethods = {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterPool[K];
};
export declare type CurrentStoreApi = {
    [K in keyof StoreApi<CommonAdapterPool>]: AdapterPool[K];
};
export declare type ConnectionDependencies = InternalMethods & ExternalMethods & CurrentStoreApi;
export declare type CurrentConnectMethod = (imports: ConnectionDependencies, ...args: Parameters<CurrentAdapterConnection['connect']>) => ReturnType<CurrentAdapterConnection['connect']>;
export declare type CurrentDisconnectMethod = CurrentAdapterConnection['disconnect'];
export declare type CurrentAdapterImplementation = AdapterImplementation<AdapterPool, AdapterOptions>;
